@@ -8,13 +8,6 @@ try:
 except ImportError:
     pass
 
-try:
-    # python3
-    IOPipeError = BrokenPipeError
-except NameError:
-    # python2
-    IOPipeError = IOError
-
 
 def main():
     from py3status.argparsers import parse_cli_args
@@ -43,7 +36,7 @@ def main():
     try:
         py3 = Py3statusWrapper(options)
         py3.setup()
-    except (IOPipeError, KeyboardInterrupt):
+    except (BrokenPipeError, KeyboardInterrupt):
         if py3:
             py3.notify_user("Setup interrupted")
         sys.exit(0)
@@ -57,7 +50,7 @@ def main():
 
     try:
         py3.run()
-    except (IOPipeError, KeyboardInterrupt):
+    except (BrokenPipeError, KeyboardInterrupt):
         pass
     except Exception:
         py3.report_exception("Runtime error")
