@@ -302,6 +302,9 @@ class Py3status:
         for path in path_its:
             r = _parse_battery_info(path)
 
+            if not r:
+                continue
+
             capacity = r.get(
                 "POWER_SUPPLY_ENERGY_FULL", r.get("POWER_SUPPLY_CHARGE_FULL")
             )
@@ -315,21 +318,31 @@ class Py3status:
             current_now = r.get("POWER_SUPPLY_CURRENT_NOW", 0)
             voltage_now = r.get("POWER_SUPPLY_VOLTAGE_NOW", 0)
 
+            # missing values may indicate this is not a battery and should be skipped
+            if (
+                capacity is None
+                or present_rate is None
+                or remaining_energy is None
+                or current_now is None
+                or voltage_now is None
+            ):
+                continue
+
             battery = {}
             battery["capacity"] = capacity
             battery["charging"] = "Charging" in r["POWER_SUPPLY_STATUS"]
             battery["percent_charged"] = int(
                 math.floor(remaining_energy / capacity * 100)
             )
-            try:
+            if present_rate == 0:
+                # Battery is either full charged or is not discharging
+                battery["time_remaining"] = FULLY_CHARGED
+            else:
                 if battery["charging"]:
                     time_in_secs = (capacity - remaining_energy) / present_rate * 3600
                 else:
                     time_in_secs = remaining_energy / present_rate * 3600
                 battery["time_remaining"] = self._seconds_to_hms(time_in_secs)
-            except ZeroDivisionError:
-                # Battery is either full charged or is not discharging
-                battery["time_remaining"] = FULLY_CHARGED
 
             battery["power"] = current_now * voltage_now / 1e12
 
