@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display date and time.
 
@@ -38,6 +37,9 @@ Configuration parameters:
         a list.  The one used can be changed by button click.
         *(default ['[{name_unclear} ]%c', '[{name_unclear} ]%x %X',
         '[{name_unclear} ]%a %H:%M', '[{name_unclear} ]{icon}'])*
+    locale: Override the system locale. Examples:
+        when set to 'fr_FR' %a on Tuesday is 'mar.'.
+        (default None)
     round_to_nearest_block: defines how a block icon is chosen. Examples:
         when set to True,  '13:14' is '🕐', '13:16' is '🕜' and '13:31' is '🕜';
         when set to False, '13:14' is '🕐', '13:16' is '🕐' and '13:31' is '🕜'.
@@ -87,8 +89,8 @@ SAMPLE OUTPUT
 london
 {'full_text': 'Thursday Feb 23 1:42 AM London'}
 """
-from __future__ import division
 
+import locale
 import re
 from datetime import datetime
 from time import time
@@ -96,7 +98,7 @@ from time import time
 import pytz
 import tzlocal
 
-CLOCK_BLOCKS = u"🕛🕧🕐🕜🕑🕝🕒🕞🕓🕟🕔🕠🕕🕡🕖🕢🕗🕣🕘🕤🕙🕥🕚🕦"
+CLOCK_BLOCKS = "🕛🕧🕐🕜🕑🕝🕒🕞🕓🕟🕔🕠🕕🕡🕖🕢🕗🕣🕘🕤🕙🕥🕚🕦"
 
 
 class Py3status:
@@ -117,9 +119,13 @@ class Py3status:
         "[{name_unclear} ]%a %H:%M",
         "[{name_unclear} ]{icon}",
     ]
+    locale = None
     round_to_nearest_block = True
 
     def post_config_hook(self):
+        if self.locale is not None:
+            locale.setlocale(locale.LC_TIME, self.locale)
+
         # Multiple clocks are possible that can be cycled through
         if not isinstance(self.format, list):
             self.format = [self.format]
@@ -183,26 +189,6 @@ class Py3status:
         # reset the cycle time
         self._cycle_time = time() + self.cycle
 
-        # set our _fmt_strftime function depending on python version
-        if self.py3.is_python_2():
-            self._fmt_strftime = self._fmt_strftime_py2
-        else:
-            self._fmt_strftime = self._fmt_strftime_py3
-
-    @staticmethod
-    def _fmt_strftime_py2(fmt, t):
-        """
-        strftime for python 2
-        """
-        return t.strftime(fmt.encode("utf-8"))
-
-    @staticmethod
-    def _fmt_strftime_py3(fmt, t):
-        """
-        strftime for python 3
-        """
-        return t.strftime(fmt)
-
     def _get_timezone(self, tz):
         """
         Find and return the time zone if possible
@@ -304,9 +290,9 @@ class Py3status:
 
                 if self.py3.is_composite(format_time):
                     for item in format_time:
-                        item["full_text"] = self._fmt_strftime(item["full_text"], t)
+                        item["full_text"] = t.strftime(item["full_text"])
                 else:
-                    format_time = self._fmt_strftime(format_time, t)
+                    format_time = t.strftime(format_time)
                 times[name] = format_time
 
         # work out when we need to update
