@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display average system load over a period of time.
 
 In UNIX computing, the system load is a measure of the amount of computational
@@ -35,7 +34,7 @@ Notes:
 Examples:
 ```
 # show load averages with static colors
-conky {
+loadavg {
     format = 'Loadavg [\?color=orange {1min} ][\?color=gold {5min} {15min}]'
 }
 
@@ -119,6 +118,7 @@ loadavg {
 loadavg {
     format = "..."
 }
+```
 
 @author lasers
 
@@ -209,7 +209,8 @@ class Py3status:
     # available configuration parameters
     cache_timeout = 5
     format = (
-        "Loadavg [\?color=1avg {1min}] " "[\?color=5avg {5min}] [\?color=15avg {15min}]"
+        r"Loadavg [\?color=1avg {1min}] "
+        r"[\?color=5avg {5min}] [\?color=15avg {15min}]"
     )
     thresholds = [
         (0, "#9dd7fb"),
